/******************************************************************************************/
/*                                                                                        */
/* Program Definitions (Constants)                                                        */
/*                                                                                        */
/******************************************************************************************/

#define PI 3.1415987		// The mathematical PI

/******************************************************************************************/
/*                                                                                        */
/* Program Type Definitions (Constants)                                                   */
/*                                                                                        */
/******************************************************************************************/

/**************************/
/* Vertices and Colors    */
/**************************/

typedef GLfloat vertex3[3];
typedef GLfloat RGBA[4];

/**************************/
/* Image Headers          */
/**************************/

typedef struct
{
	GLbyte *data;
	GLint width,height,components;
	GLenum format;
} IMAGE;

/* .TGA */
typedef struct
    {
    GLbyte	identsize;					// Size of ID field that follows header (0)
    GLbyte	colorMapType;				// 0 = None, 1 = paletted
    GLbyte	imageType;					// 0 = none, 1 = indexed, 2 = rgb, 3 = grey, +8=rle
    unsigned short	colorMapStart;      // First colour map entry
    unsigned short	colorMapLength;     // Number of colors
    unsigned char 	colorMapBits;		// bits per palette entry
    unsigned short	xstart;             // image x origin
    unsigned short	ystart;             // image y origin
    unsigned short	width;              // width in pixels
    unsigned short	height;             // height in pixels
    GLbyte	bits;						// bits per pixel (8 16, 24, 32)
    GLbyte	descriptor;					// image descriptor
    } TGAHEADER;


/**************************/
/* Lights                 */
/**************************/

typedef struct 
{
	GLfloat ambient[4];
	GLfloat diffuse[4];
	GLfloat specular[4];
	
	GLfloat pos[4];
	GLfloat dir[3];
} Light;

/**************************/
/* Materials              */
/**************************/

typedef struct 
{
 GLfloat ambient[3];
 GLfloat diffuse[3];
 GLfloat specular[3];
 GLfloat emission[3];
 GLfloat alpha;
 GLfloat phExp;
 int   texture;
} MATERIAL;


/**************************/
/* Actors                 */
/**************************/

typedef struct 
{
	vertex3 Pos;
	vertex3 Up;
	vertex3 Front;
	vertex3 Right;
	vertex3 Theta;
} ACTOR_POS;